@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 """ ctypes wrapper for AudioScience HPI library
 
 This is a very thin wrapper around the HPI C API,
@@ -25,7 +25,7 @@ Note: brief benchmark suggest negligible slowdown compared with SWIG wrapper
 
 (c) AudioScience Inc 2010-2011
 """
-from __future__ import print_function
+
 
 __version__ = "1.0.0"
 
@@ -605,11 +605,11 @@ def make_dict(root, d):
     list of strings is passed in in d,  only symbols starting with string root are included'''
     n = [x for x in d if (x.startswith(root) and not (x.endswith('SET') or x.endswith('QUERY'))) ]
     v = [eval(s) for s in n]
-    return dict(zip(v,n))
+    return dict(list(zip(v,n)))
 
 def reverse_dict(d):
     '''Create a dict with keys and values swapped from the input dict'''
-    return dict((v,k) for k, v in d.iteritems())
+    return dict((v,k) for k, v in d.items())
 
 AdapterModeDict = make_dict('ADAPTER_MODE_', d)
 AdapterPropertyDict = make_dict('ADAPTER_PROPERTY_', d)
@@ -770,7 +770,7 @@ def print_entity(ent, level=0):
     print('%s %s[%d]' % (stype, srole, i), end='')
 
     if t == entity_type_sequence:
-        print
+        print()
         current = entity()
         while True:
             e, current = Entity_FindNext(ent, entity_type_null, entity_role_null, 0, current)
