@@ -1,8 +1,8 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 #
 # hpi commandline Swiss army knife
 #
-from __future__ import print_function
+
 
 usage = """hpicontrol.py [options] command <cmd arguments>
 
@@ -445,7 +445,7 @@ def ModeInfo(adapter):
     '''
     e,cm = hpi.Adapter_GetMode(adapter)
     if not e:
-        for m,n in hpi.AdapterModeDict.items():
+        for m,n in list(hpi.AdapterModeDict.items()):
             e = hpi.Adapter_SetModeEx(adapter,m, hpi.ADAPTER_MODE_QUERY)
             if not e:
                 if m == cm:
@@ -461,7 +461,7 @@ def PropInfo(adapter):
     '''
     print('Properties')
     lp = []
-    for k,n in hpi.AdapterPropertyDict.items():
+    for k,n in list(hpi.AdapterPropertyDict.items()):
         e,p1,p2 = hpi.Adapter_GetProperty(adapter, k)
         if not e:
             lp.append('%3d %-40s %5d %5d' % (k,n,p1,p2))
