@@ -62,10 +62,7 @@ Hardware Programming Interface (HPI) for AudioScience
 #define HPI6700_POLL_DSP_ACK
 #endif
 
-#define H670_CONTROLCACHEESTIMATE (HPI_NMIXER_CONTROLS * sizeof(struct hpi_control_cache_meter))
-#define H670_HIF_BUFFER_SIZE \
-		(sizeof(struct bus_master_interface_67) + \
-		H670_CONTROLCACHEESTIMATE)
+#define H670_HIF_BUFFER_SIZE (sizeof(struct bus_master_interface_67))
 
 #ifndef HPI_BUILD_SANITISE
 typedef volatile struct bus_master_interface_67 tBusMasteringInterfaceBuffer;
@@ -120,6 +117,7 @@ struct hpi_hw_stream_obj_67 {
 
 struct hpi_hw_obj_67 {
 	HpiOs_LockedMem_Handle hLockedMem;
+	HpiOs_LockedMem_Handle hLockedMemCache;
 	struct bus_master_interface_67 *pInterfaceBuffer;
 	uint32_t dwInterfaceBufferPhysAddr;
 	uint32_t dwMessageInterruptCount;
@@ -1448,11 +1446,8 @@ static hpi_err_t SetupBars(struct hpi_adapter_obj *pao)
 		phw->bar[i].size = pci_resource_len(pci_dev, i);
 	}
 
-	i = dma_set_min_align_mask(&pci_dev->dev, LINUX_DEV_DMA_BUFFER_ALIGNMENT-1);
-	if (i) {
-		dev_err(&pci_dev->dev, "Failed to set DMA buffer alignment mask to %d\n", LINUX_DEV_DMA_BUFFER_ALIGNMENT-1);
-		return HPI_ERROR_MEMORY_ALLOC;
-	}
+	// Starting from Linux 6.12, the return value of dma_set_min_align_mask must be ignored
+	dma_set_min_align_mask(&pci_dev->dev, LINUX_DEV_DMA_BUFFER_ALIGNMENT-1);
 
 	return 0;
 }
@@ -1613,7 +1608,6 @@ static int _HPI6700_adapter_init(struct hpi_adapter_obj *pao)
 	struct bus_master_interface_67 *interface;
 #if HIF_BUFFER_ALIGNMENT
 	uint32_t alignment_offset = 0;
-	uint32_t misaligned_by;
 #endif
 	int i;
 	int err;
@@ -1642,7 +1636,7 @@ static int _HPI6700_adapter_init(struct hpi_adapter_obj *pao)
 	}
 
 	phw->pInterfaceBuffer = HpiOs_LockedMem_Alloc(&phw->hLockedMem,
-			H670_HIF_BUFFER_SIZE + HIF_BUFFER_ALIGNMENT, &pao->os,
+			HpiOs_BoundaryFreeBufferAllocSize(H670_HIF_BUFFER_SIZE), &pao->os,
 			&phw->dwInterfaceBufferPhysAddr);
 	if (!phw->pInterfaceBuffer)
 		return HPI_ERROR_MEMORY_ALLOC;
@@ -1650,12 +1644,11 @@ static int _HPI6700_adapter_init(struct hpi_adapter_obj *pao)
 	HPI_DEBUG_LOG3(DEBUG,
 		"Interface buffer (unaligned) virtual addr: %p, phys addr: %x, size: %lu\n",
 		phw->pInterfaceBuffer, phw->dwInterfaceBufferPhysAddr,
-		(unsigned long)H670_HIF_BUFFER_SIZE);
+		(unsigned long)HpiOs_BoundaryFreeBufferAllocSize(H670_HIF_BUFFER_SIZE));
 
 #if HIF_BUFFER_ALIGNMENT
-	misaligned_by = phw->dwInterfaceBufferPhysAddr % HIF_BUFFER_ALIGNMENT;
-	if (misaligned_by)
-		alignment_offset = HIF_BUFFER_ALIGNMENT - misaligned_by;
+	alignment_offset = HpiOs_BoundaryFreeBufferOffset(H670_HIF_BUFFER_SIZE, 
+			HIF_BUFFER_ALIGNMENT, phw->dwInterfaceBufferPhysAddr);
 
 	HPI_DEBUG_LOG1(DEBUG,
 		"Interface buffer alignment offset: %d\n",
@@ -1696,53 +1689,51 @@ static int _HPI6700_adapter_init(struct hpi_adapter_obj *pao)
 	 * Allocate bus mastering control cache buffer and tell the DSP about it
 	 */
 	if (interface->aControlCache.dwNumberOfControls) {
-		uint32_t misaligned_by;
+#if HIF_BUFFER_ALIGNMENT
 		uint32_t alignment_offset;
+#endif
 		uint8_t *pControlCacheVirtual;
-		uint8_t *pControlCacheLastByte;
+		uint32_t pControlCachePhysical;
 
-		// next 16-byte boundary past end of interface buffer
-		misaligned_by = (phw->dwInterfaceBufferPhysAddr +
-			sizeof(struct bus_master_interface_67)) % LINE_ALIGNMENT;
-		if (misaligned_by)
-			alignment_offset = LINE_ALIGNMENT - misaligned_by;
-		else
-			alignment_offset = 0;
+		pControlCacheVirtual = HpiOs_LockedMem_Alloc(&phw->hLockedMemCache,
+				HpiOs_BoundaryFreeBufferAllocSize(interface->aControlCache.dwSizeInBytes), &pao->os,
+				&pControlCachePhysical);
+		if (!pControlCacheVirtual)
+			return HPI_ERROR_MEMORY_ALLOC;
 
-		pControlCacheVirtual = (uint8_t *)phw->pInterfaceBuffer +
-			sizeof(struct bus_master_interface_67) +
-			alignment_offset;
+		HPI_DEBUG_LOG3(DEBUG,
+			"Cache buffer (unaligned) virtual addr: %p, phys addr: %x, size: %lu\n",
+			pControlCacheVirtual, pControlCachePhysical,
+			(unsigned long)HpiOs_BoundaryFreeBufferAllocSize(interface->aControlCache.dwSizeInBytes));
 
-		// verify that it fits
-		pControlCacheLastByte = pControlCacheVirtual +
-			interface->aControlCache.dwSizeInBytes - 1;
+#if HIF_BUFFER_ALIGNMENT
+		alignment_offset = HpiOs_BoundaryFreeBufferOffset(interface->aControlCache.dwSizeInBytes, 
+				HIF_BUFFER_ALIGNMENT, pControlCachePhysical);
 
-		if (HpiOs_LockedMem_ValidAddr(&phw->hLockedMem, pControlCacheLastByte))
-		{
-			phw->pCache = HpiAllocControlCache(
+		HPI_DEBUG_LOG1(DEBUG,
+			"Interface buffer alignment offset: %d\n",
+			alignment_offset);
+
+		pControlCachePhysical += alignment_offset;
+		pControlCacheVirtual = (uint8_t *)pControlCacheVirtual + alignment_offset;
+#endif
+
+		phw->pCache = HpiAllocControlCache(
+			interface->aControlCache.dwNumberOfControls,
+			interface->aControlCache.dwSizeInBytes,
+			pControlCacheVirtual);
+
+		if (phw->pCache){
+			pao->wHasControlCache = 1;
+			interface->aControlCache.dwPhysicalAddress32 = pControlCachePhysical;
+			HPI_DEBUG_LOG3(DEBUG,
+				"Successfully allocated cache for %d controls %d bytes at %x\n",
 				interface->aControlCache.dwNumberOfControls,
 				interface->aControlCache.dwSizeInBytes,
-				pControlCacheVirtual);
-			if (phw->pCache){
-				pao->wHasControlCache = 1;
-				interface->aControlCache.dwPhysicalAddress32 =
-					phw->dwInterfaceBufferPhysAddr +
-					sizeof(struct bus_master_interface_67) +
-					alignment_offset;
-				HPI_DEBUG_LOG3(DEBUG,
-					"Successfully allocated cache for %d controls %d bytes at %x\n",
-					interface->aControlCache.dwNumberOfControls,
-					interface->aControlCache.dwSizeInBytes,
-					interface->aControlCache.dwPhysicalAddress32);
-			} else {
-				HPI_DEBUG_LOG0(ERROR,
-					"HpiAllocControlCache() failed\n");
-			}
+				interface->aControlCache.dwPhysicalAddress32);
 		} else {
-			HPI_DEBUG_LOG1(ERROR,
-				"Allocated memory doesn't have room for %d byte control cache!\n",
-				interface->aControlCache.dwSizeInBytes);
-			return HPI_ERROR_MEMORY_ALLOC;
+			HPI_DEBUG_LOG0(ERROR,
+				"HpiAllocControlCache() failed\n");
 		}
 	}
 
@@ -2312,6 +2303,9 @@ static hpi_err_t AdapterBootLoadDsp(struct hpi_adapter_obj *pao)
 	HPI_DEBUG_LOG1(DEBUG, "Set bar 2 to phymem location (address %8.8X)\n", soc_phymem_location);
 
 	switch (HPIOS_PCI_SUBSYS_DEVICE(pao) & 0xfff0) {
+	case 0x5750:
+		aBootCodeId = HPI_ADAPTER_ASI(0x5752);
+		break;
 	case 0x6790:
 		aBootCodeId = HPI_ADAPTER_ASI(0x6790);
 		break;
