@@ -201,6 +201,15 @@ uint16_t HpiOs_LockedMem_ValidAddr(
 #endif
 #endif
 
+#define HpiOs_BoundaryFreeBufferAllocSize(size) \
+		( size * 2 )
+
+#define HpiOs_NextBoundary(addr,interval) (( addr + interval ) & ~(interval-1))
+
+#define HpiOs_BoundaryFreeBufferOffset(size, interval, addr) \
+		( ( ( addr + size ) <= HpiOs_NextBoundary(addr,interval) ) ? \
+			( 0 ) : ( HpiOs_NextBoundary(addr,interval) - addr ) )
+			
 #endif
 
 /* timing/delay */
